@@ -10,7 +10,7 @@ class RabbitSpider(scrapy.Spider):
 
         data = json.loads(body,encoding="utf-8")
         if self.settings.get("PYPPETEER_ENABLE"):
-            data['params']['pyppeteer'] = self.settings.get("PYPPETEER_ENABLE")
+            data['params']['pyppeteer'] = self.settings.get("PYPPETEER_ENABLE",False)
         request = scrapy.Request(data['url'], callback=self.parse, dont_filter=True,meta=data['params'])
 
         return request
